/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <ksharedconfig.h>

#include <qbytearray.h>
#include <kconfigbase.h>
#include <kconfiggroup.h>
#include <qstring.h>
#include <qmap.h>
#include <qstringlist.h>
#include <kconfig.h>
#include <kconfigbase.h>
#include <kconfig.h>
#include <qstandardpaths.h>


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_KSharedConfig(void *, const sipTypeDef *);}
static void *cast_KSharedConfig(void *sipCppV, const sipTypeDef *targetType)
{
     ::KSharedConfig *sipCpp = reinterpret_cast< ::KSharedConfig *>(sipCppV);

    if (targetType == sipType_KConfig)
        return static_cast< ::KConfig *>(sipCpp);

    if (targetType == sipType_KConfigBase)
        return static_cast< ::KConfigBase *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_KSharedConfig(void *, int);}
static void release_KSharedConfig(void *sipCppV, int)
{
    delete reinterpret_cast< ::KSharedConfig *>(sipCppV);
}


extern "C" {static void dealloc_KSharedConfig(sipSimpleWrapper *);}
static void dealloc_KSharedConfig(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_KSharedConfig(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_KSharedConfig[] = {{2, 255, 1}};


static pyqt5ClassPluginDef plugin_KSharedConfig = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KSharedConfig = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KSharedConfig,
        {0},
        &plugin_KSharedConfig
    },
    {
        sipNameNr_KSharedConfig,
        {0, 0, 1},
        0, 0,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    supers_KSharedConfig,
    0,
    0,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KSharedConfig,
    0,
    0,
    0,
    release_KSharedConfig,
    cast_KSharedConfig,
    0,
    0,
    0,
    0,
    0,
    0
};
