/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kauthorized.h>

#include <qstring.h>
#include <qstringlist.h>


extern "C" {static PyObject *meth_KAuthorized_authorizeControlModules(PyObject *, PyObject *);}
static PyObject *meth_KAuthorized_authorizeControlModules(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QStringList* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QStringList,&a0, &a0State))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList( ::KAuthorized::authorizeControlModules(*a0));
            sipReleaseType(const_cast< ::QStringList *>(a0),sipType_QStringList,a0State);

            return sipConvertFromNewType(sipRes,sipType_QStringList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_authorizeControlModules, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KAuthorized_authorizeControlModule(PyObject *, PyObject *);}
static PyObject *meth_KAuthorized_authorizeControlModule(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KAuthorized::authorizeControlModule(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_authorizeControlModule, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KAuthorized_authorizeKAction(PyObject *, PyObject *);}
static PyObject *meth_KAuthorized_authorizeKAction(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KAuthorized::authorizeKAction(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_authorizeKAction, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KAuthorized_authorizeAction(PyObject *, PyObject *);}
static PyObject *meth_KAuthorized_authorizeAction(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KAuthorized::authorizeAction(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_authorizeAction, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KAuthorized_authorize(PyObject *, PyObject *);}
static PyObject *meth_KAuthorized_authorize(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KAuthorized::authorize(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_authorize, NULL);

    return NULL;
}


static PyMethodDef methods_KAuthorized[] = {
    {SIP_MLNAME_CAST(sipName_authorize), meth_KAuthorized_authorize, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_authorizeAction), meth_KAuthorized_authorizeAction, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_authorizeControlModule), meth_KAuthorized_authorizeControlModule, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_authorizeControlModules), meth_KAuthorized_authorizeControlModules, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_authorizeKAction), meth_KAuthorized_authorizeKAction, METH_VARARGS, NULL}
};


static pyqt5ClassPluginDef plugin_KAuthorized = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KAuthorized = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_NAMESPACE,
        sipNameNr_KAuthorized,
        {0},
        &plugin_KAuthorized
    },
    {
        sipNameNr_KAuthorized,
        {0, 0, 1},
        5, methods_KAuthorized,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    0,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
