/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigGui.h"

#include <kconfiggui.h>

#include <kconfig.h>
#include <qstring.h>


extern "C" {static PyObject *meth_KConfigGui_sessionConfigName(PyObject *, PyObject *);}
static PyObject *meth_KConfigGui_sessionConfigName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::KConfigGui::sessionConfigName());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_sessionConfigName, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigGui_hasSessionConfig(PyObject *, PyObject *);}
static PyObject *meth_KConfigGui_hasSessionConfig(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            bool sipRes;

            sipRes =  ::KConfigGui::hasSessionConfig();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_hasSessionConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigGui_setSessionConfig(PyObject *, PyObject *);}
static PyObject *meth_KConfigGui_setSessionConfig(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1J1", sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State))
        {
             ::KConfigGui::setSessionConfig(*a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_setSessionConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigGui_sessionConfig(PyObject *, PyObject *);}
static PyObject *meth_KConfigGui_sessionConfig(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
             ::KConfig*sipRes;

            sipRes =  ::KConfigGui::sessionConfig();

            return sipConvertFromType(sipRes,sipType_KConfig,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_sessionConfig, NULL);

    return NULL;
}


static PyMethodDef methods_KConfigGui[] = {
    {SIP_MLNAME_CAST(sipName_hasSessionConfig), meth_KConfigGui_hasSessionConfig, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_sessionConfig), meth_KConfigGui_sessionConfig, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_sessionConfigName), meth_KConfigGui_sessionConfigName, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setSessionConfig), meth_KConfigGui_setSessionConfig, METH_VARARGS, NULL}
};


static pyqt5ClassPluginDef plugin_KConfigGui = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigGui_KConfigGui = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_NAMESPACE,
        sipNameNr_KConfigGui,
        {0},
        &plugin_KConfigGui
    },
    {
        sipNameNr_KConfigGui,
        {0, 0, 1},
        4, methods_KConfigGui,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    0,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
