/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <qlist.h>

#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>


extern "C" {static void assign_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *, SIP_SSIZE_T, const void *);}
static void assign_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *sipDst, SIP_SSIZE_T sipDstIdx, const void *sipSrc)
{
    reinterpret_cast<QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *>(sipDst)[sipDstIdx] = *reinterpret_cast<const QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *>(sipSrc);
}


extern "C" {static void *array_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(SIP_SSIZE_T);}
static void *array_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(SIP_SSIZE_T sipNrElem)
{
    return new QList< ::KCoreConfigSkeleton::ItemEnum::Choice>[sipNrElem];
}


extern "C" {static void *copy_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(const void *, SIP_SSIZE_T);}
static void *copy_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new QList< ::KCoreConfigSkeleton::ItemEnum::Choice>(reinterpret_cast<const QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *>(sipSrc)[sipSrcIdx]);
}


/* Call the mapped type's destructor. */
extern "C" {static void release_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *, int);}
static void release_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *ptr, int)
{
    delete reinterpret_cast<QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *>(ptr);
}



extern "C" {static int convertTo_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(PyObject *, void **, int *, PyObject *);}
static int convertTo_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(PyObject *sipPy,void **sipCppPtrV,int *sipIsErr,PyObject *sipTransferObj)
{
    QList< ::KCoreConfigSkeleton::ItemEnum::Choice> **sipCppPtr = reinterpret_cast<QList< ::KCoreConfigSkeleton::ItemEnum::Choice> **>(sipCppPtrV);

    PyObject *iter = PyObject_GetIter(sipPy);

    if (!sipIsErr)
    {
        Py_XDECREF(iter);

        return (iter
#if PY_MAJOR_VERSION < 3
                && !PyString_Check(sipPy)
#endif
                && !PyUnicode_Check(sipPy));
    }

    if (!iter)
    {
        *sipIsErr = 1;

        return 0;
    }

    QList<KCoreConfigSkeleton::ItemEnum::Choice> *ql = new QList<KCoreConfigSkeleton::ItemEnum::Choice>;
 
    for (Py_ssize_t i = 0; ; ++i)
    {
        PyErr_Clear();
        PyObject *itm = PyIter_Next(iter);

        if (!itm)
        {
            if (PyErr_Occurred())
            {
                delete ql;
                Py_DECREF(iter);
                *sipIsErr = 1;

                return 0;
            }

            break;
        }

        int state;
        KCoreConfigSkeleton::ItemEnum::Choice *t = reinterpret_cast<KCoreConfigSkeleton::ItemEnum::Choice *>(
                sipForceConvertToType(itm, sipType_KCoreConfigSkeleton_ItemEnum_Choice, sipTransferObj,
                        SIP_NOT_NONE, &state, sipIsErr));

        if (*sipIsErr)
        {
            PyErr_Format(PyExc_TypeError,
                    "index %zd has type '%s' but 'KCoreConfigSkeleton::ItemEnum::Choice' is expected", i,
                    sipPyTypeName(Py_TYPE(itm)));

            Py_DECREF(itm);
            delete ql;
            Py_DECREF(iter);

            return 0;
        }

        ql->append(*t);

        sipReleaseType(t, sipType_KCoreConfigSkeleton_ItemEnum_Choice, state);
        Py_DECREF(itm);
    }
 
    Py_DECREF(iter);

    *sipCppPtr = ql;
 
    return sipGetState(sipTransferObj);
}


extern "C" {static PyObject *convertFrom_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *, PyObject *);}
static PyObject *convertFrom_QList_0100KCoreConfigSkeleton_ItemEnum_Choice(void *sipCppV, PyObject *sipTransferObj)
{
   QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *sipCpp = reinterpret_cast<QList< ::KCoreConfigSkeleton::ItemEnum::Choice> *>(sipCppV);

    PyObject *l = PyList_New(sipCpp->size());

    if (!l)
        return 0;

    for (int i = 0; i < sipCpp->size(); ++i)
    {
        KCoreConfigSkeleton::ItemEnum::Choice *t = new KCoreConfigSkeleton::ItemEnum::Choice(sipCpp->at(i));
        PyObject *tobj = sipConvertFromNewType(t, sipType_KCoreConfigSkeleton_ItemEnum_Choice,
                sipTransferObj);

        if (!tobj)
        {
            delete t;
            Py_DECREF(l);

            return 0;
        }

        PyList_SetItem(l, i, tobj);
    }

    return l;
}


sipMappedTypeDef sipTypeDef_KConfigCore_QList_0100KCoreConfigSkeleton_ItemEnum_Choice = {
    {
        -1,
        0,
        0,
        SIP_TYPE_MAPPED,
        sipNameNr_0,     /* QList<KCoreConfigSkeleton::ItemEnum::Choice> */
        {0},
        0
    },
    {
        -1,
        {0, 0, 1},
        0, 0,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    },
    assign_QList_0100KCoreConfigSkeleton_ItemEnum_Choice,
    array_QList_0100KCoreConfigSkeleton_ItemEnum_Choice,
    copy_QList_0100KCoreConfigSkeleton_ItemEnum_Choice,
    release_QList_0100KCoreConfigSkeleton_ItemEnum_Choice,
    convertTo_QList_0100KCoreConfigSkeleton_ItemEnum_Choice,
    convertFrom_QList_0100KCoreConfigSkeleton_ItemEnum_Choice
};
