/*
 * Module code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigGui.h"

#include <qobject.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qvariant.h>
#include <kconfig.h>

/* Define the strings used by this module. */
const char sipStrings_KConfigGui[] = {
    'K', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', ':', ':', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'C', 'o', 'l', 'o', 'r', 0,
    'S', 'w', 'i', 't', 'c', 'h', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    'h', 'a', 'r', 'd', 'c', 'o', 'd', 'e', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'u', 'b', 's', 't', 'r', 'i', 'n', 'g', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'S', 'u', 'b', 's', 't', 'r', 'i', 'n', 'g', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'r', 'e', 's', 't', 'o', 'r', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'W', 'o', 'r', 'd', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 'T', 'o', 'o', 'l', 'b', 'a', 'r', 's', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'W', 'o', 'r', 'd', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'K', 'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'C', 'o', 'n', 'f', 'i', 'g', 'N', 'a', 'm', 'e', 0,
    'i', 's', 'S', 'i', 'g', 'n', 'a', 'l', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    's', 'e', 'n', 'd', 'e', 'r', 'S', 'i', 'g', 'n', 'a', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    'h', 'a', 's', 'S', 'e', 's', 's', 'i', 'o', 'n', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    's', 'e', 't', 'S', 'e', 's', 's', 'i', 'o', 'n', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'r', 'e', 'a', 'd', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'P', 'y', 'K', 'F', '5', '.', 'K', 'C', 'o', 'n', 'f', 'i', 'g', 'G', 'u', 'i', 0,
    'b', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'B', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', '_', 'f', 'o', 'r', 'm', 'a', 't', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'M', 'o', 'd', 'e', 0,
    's', 'a', 'v', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'i', 'z', 'e', 0,
    'n', 'e', 'x', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 'v', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'W', 'o', 'r', 'd', 'B', 'a', 'c', 'k', 0,
    'p', 'a', 's', 't', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'N', 'e', 'x', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'P', 'r', 'e', 'v', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'T', 'e', 'x', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'W', 'o', 'r', 'd', 'B', 'a', 'c', 'k', 0,
    'P', 'a', 's', 't', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'f', 'i', 'n', 'd', 'I', 't', 'e', 'm', 'B', 'y', 'N', 'a', 'm', 'e', 0,
    'u', 's', 'r', 'W', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'u', 's', 'r', 'S', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'u', 's', 'r', 'U', 's', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'K', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'S', 'h', 'o', 'w', 'S', 't', 'a', 't', 'u', 's', 'b', 'a', 'r', 0,
    'E', 'd', 'i', 't', 'B', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 's', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'L', 'o', 'a', 'd', 'e', 'r', 0,
    's', 'e', 's', 's', 'i', 'o', 'n', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'u', 's', 'r', 'R', 'e', 'a', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 0,
    'b', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 'W', 'o', 'r', 'd', 0,
    's', 'a', 'v', 'e', 'S', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'B', 'a', 'c', 'k', 0,
    'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 0,
    'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 'W', 'o', 'r', 'd', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'C', 'o', 'l', 'o', 'r', 0,
    'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'm', 'o', 'v', 'e', 'T', 'o', 'T', 'r', 'a', 's', 'h', 0,
    's', 'h', 'o', 'w', 'M', 'e', 'n', 'u', 'b', 'a', 'r', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'W', 'o', 'r', 'd', 0,
    'a', 'd', 'd', 'B', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 0,
    'M', 'o', 'v', 'e', 'T', 'o', 'T', 'r', 'a', 's', 'h', 0,
    'K', 'e', 'y', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 's', 0,
    'S', 'a', 'v', 'e', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'S', 'h', 'o', 'w', 'T', 'o', 'o', 'l', 'b', 'a', 'r', 0,
    'F', 'i', 't', 'T', 'o', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'S', 'h', 'o', 'w', 'M', 'e', 'n', 'u', 'b', 'a', 'r', 0,
    'A', 'd', 'd', 'B', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 0,
    'F', 'o', 'r', 'w', 'a', 'r', 'd', 'W', 'o', 'r', 'd', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'F', 'o', 'n', 't', 0,
    'u', 's', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    's', 'w', 'a', 'p', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'r', 'e', 'a', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'w', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'm', 'a', 't', 'c', 'h', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'r', 'e', 'n', 'a', 'm', 'e', 'F', 'i', 'l', 'e', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'F', 'i', 'l', 'e', 0,
    'r', 'o', 't', 'a', 't', 'e', 'D', 'o', 'w', 'n', 0,
    'c', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 0,
    'f', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'R', 'e', 'n', 'a', 'm', 'e', 'F', 'i', 'l', 'e', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'F', 'i', 'l', 'e', 0,
    'F', 'i', 't', 'T', 'o', 'W', 'i', 'd', 't', 'h', 0,
    'A', 'c', 't', 'u', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'O', 'p', 'e', 'n', 'R', 'e', 'c', 'e', 'n', 't', 0,
    'R', 'o', 't', 'a', 't', 'e', 'D', 'o', 'w', 'n', 0,
    'r', 'e', 'a', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'g', 'e', 'n', 'M', 'i', 'p', 'M', 'a', 'p', 's', 0,
    'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'e', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    'R', 'e', 'p', 'o', 'r', 't', 'B', 'u', 'g', 0,
    'F', 'i', 't', 'T', 'o', 'P', 'a', 'g', 'e', 0,
    'A', 'c', 'c', 'e', 'l', 'N', 'o', 'n', 'e', 0,
    'g', 'r', 'o', 'u', 'p', 'L', 'i', 's', 't', 0,
    'E', 'n', 'd', 'O', 'f', 'L', 'i', 'n', 'e', 0,
    'w', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 0,
    'r', 'e', 'c', 'e', 'i', 'v', 'e', 'r', 's', 0,
    'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    'r', 'o', 't', 'a', 't', 'e', 'U', 'p', 0,
    'g', 'o', 't', 'o', 'L', 'i', 'n', 'e', 0,
    'f', 'i', 'n', 'd', 'P', 'r', 'e', 'v', 0,
    'f', 'i', 'n', 'd', 'N', 'e', 'x', 't', 0,
    's', 'h', 'o', 'r', 't', 'c', 'u', 't', 0,
    'A', 'b', 'o', 'u', 't', 'K', 'D', 'E', 0,
    'A', 'b', 'o', 'u', 't', 'A', 'p', 'p', 0,
    'T', 'i', 'p', 'o', 'f', 'D', 'a', 'y', 0,
    'S', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 0,
    'G', 'o', 't', 'o', 'P', 'a', 'g', 'e', 0,
    'R', 'o', 't', 'a', 't', 'e', 'U', 'p', 0,
    'G', 'o', 't', 'o', 'L', 'i', 'n', 'e', 0,
    'F', 'i', 'n', 'd', 'P', 'r', 'e', 'v', 0,
    'f', 'i', 'n', 'd', 'I', 't', 'e', 'm', 0,
    'm', 'a', 'x', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'i', 'n', 'V', 'a', 'l', 'u', 'e', 0,
    'h', 'a', 's', 'G', 'r', 'o', 'u', 'p', 0,
    'f', 'i', 'l', 'l', 'R', 'u', 'l', 'e', 0,
    'F', 'i', 'n', 'd', 'N', 'e', 'x', 't', 0,
    't', 'a', 'b', 'A', 'r', 'r', 'a', 'y', 0,
    't', 'a', 'b', 'S', 't', 'o', 'p', 's', 0,
    'n', 'a', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'D', 'e', 's', 'e', 'l', 'e', 'c', 't', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    't', 'a', 'b', 'P', 'r', 'e', 'v', 0,
    't', 'a', 'b', 'N', 'e', 'x', 't', 0,
    'z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    'o', 'p', 'e', 'n', 'N', 'e', 'w', 0,
    'T', 'a', 'b', 'P', 'r', 'e', 'v', 0,
    'T', 'a', 'b', 'N', 'e', 'x', 't', 0,
    'u', 's', 'r', 'S', 'a', 'v', 'e', 0,
    'u', 's', 'r', 'R', 'e', 'a', 'd', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'd', 0,
    'i', 's', 'E', 'q', 'u', 'a', 'l', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 0,
    's', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'Z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    'q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'f', 'i', 'l', 't', 'e', 'r', 's', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'r', 'e', 'l', 'o', 'a', 'd', 0,
    'z', 'o', 'o', 'm', 'I', 'n', 0,
    'D', 'o', 'n', 'a', 't', 'e', 0,
    'R', 'e', 'v', 'e', 'r', 't', 0,
    'R', 'e', 'l', 'o', 'a', 'd', 0,
    's', 't', 'r', 'i', 'd', 'e', 0,
    'S', 'a', 'v', 'e', 'A', 's', 0,
    'Z', 'o', 'o', 'm', 'I', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 0,
    's', 'e', 'n', 'd', 'e', 'r', 0,
    'v', 'a', 'l', 'u', 'e', '9', 0,
    'v', 'a', 'l', 'u', 'e', '8', 0,
    'v', 'a', 'l', 'u', 'e', '7', 0,
    'v', 'a', 'l', 'u', 'e', '6', 0,
    'v', 'a', 'l', 'u', 'e', '5', 0,
    'v', 'a', 'l', 'u', 'e', '4', 0,
    'v', 'a', 'l', 'u', 'e', '3', 0,
    'v', 'a', 'l', 'u', 'e', '2', 0,
    'v', 'a', 'l', 'u', 'e', '1', 0,
    'v', 'a', 'l', 'u', 'e', '0', 0,
    's', 'y', 'm', 'b', 'o', 'l', 0,
    's', 'u', 'f', 'f', 'i', 'x', 0,
    'p', 'r', 'e', 'f', 'i', 'x', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'r', 'i', 'o', 'r', 0,
    'p', 'a', 's', 't', 'e', 0,
    'p', 'r', 'i', 'n', 't', 0,
    'P', 'r', 'i', 'o', 'r', 0,
    'B', 'e', 'g', 'i', 'n', 0,
    'l', 'a', 'b', 'e', 'l', 0,
    'b', 'e', 'g', 'i', 'n', 0,
    'P', 'r', 'i', 'n', 't', 0,
    'P', 'a', 's', 't', 'e', 0,
    't', 'y', 'p', 'e', 's', 0,
    'C', 'l', 'e', 'a', 'r', 0,
    'C', 'l', 'o', 's', 'e', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'm', 's', 'e', 'c', 's', 0,
    's', 't', 'a', 't', 'e', 0,
    'b', 'a', 'c', 'k', 0,
    'h', 'e', 'l', 'p', 0,
    'G', 'o', 't', 'o', 0,
    'Z', 'o', 'o', 'm', 0,
    'M', 'a', 'i', 'l', 0,
    'H', 'e', 'l', 'p', 0,
    'H', 'o', 'm', 'e', 0,
    'r', 'e', 'd', 'o', 0,
    'u', 'n', 'd', 'o', 0,
    'f', 'i', 'n', 'd', 0,
    'Q', 'u', 'i', 't', 0,
    'F', 'i', 'n', 'd', 0,
    'R', 'e', 'd', 'o', 0,
    'U', 'n', 'd', 'o', 0,
    'C', 'o', 'p', 'y', 0,
    's', 'a', 'v', 'e', 0,
    'O', 'p', 'e', 'n', 0,
    'c', 'o', 'p', 'y', 0,
    'n', 'e', 'x', 't', 0,
    'h', 'o', 'm', 'e', 0,
    'q', 'u', 'i', 't', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'b', 'a', 's', 'e', 0,
    'o', 'p', 'e', 'n', 0,
    'f', 'r', 'o', 'm', 0,
    's', 'o', 'r', 't', 0,
    'E', 'n', 'd', 0,
    'C', 'u', 't', 0,
    'p', 'o', 's', 0,
    'e', 'n', 'd', 0,
    's', 'w', 0,
    's', 'y', 0,
    's', 'x', 0,
};

void sipVH_KConfigGui_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::KConfig*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_KConfig, NULL);
}

void sipVH_KConfigGui_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QVariant& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QVariant(a0), sipType_QVariant, NULL);
}

bool sipVH_KConfigGui_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QVariant& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "N", new  ::QVariant(a0), sipType_QVariant, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QVariant sipVH_KConfigGui_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_KConfigGui_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QMetaMethod(a0), sipType_QMetaMethod, NULL);
}

void sipVH_KConfigGui_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, NULL);
}

void sipVH_KConfigGui_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, NULL);
}

void sipVH_KConfigGui_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, NULL);
}

bool sipVH_KConfigGui_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "DD", a0, sipType_QObject, NULL, a1, sipType_QEvent, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_KConfigGui_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "D", a0, sipType_QEvent, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_KConfigGui_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_KConfigGui_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_KConfigGui_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KStandardShortcut__StandardShortcut, {0}, 0}, sipNameNr_StandardShortcut, 5, NULL},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_KConfigGui[] = {
    &sipTypeDef_KConfigGui_KConfigGui.ctd_base,
    &sipTypeDef_KConfigGui_KConfigLoader.ctd_base,
    &sipTypeDef_KConfigGui_KConfigSkeleton.ctd_base,
    &sipTypeDef_KConfigGui_KConfigSkeleton_ItemColor.ctd_base,
    &sipTypeDef_KConfigGui_KConfigSkeleton_ItemFont.ctd_base,
    &sipTypeDef_KConfigGui_KStandardShortcut.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_KConfigGui_KWindowConfig.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_KConfigGui_QtCore[] = {
    {"QChildEvent"},
    {"QEvent"},
    {"QIODevice"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {NULL}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_KConfigGui_QtCore[] = {
    {"PyQt5"},
    {NULL}
};


/* This defines the types that this module needs to import from KConfigCore. */
sipImportedTypeDef sipImportedTypes_KConfigGui_KConfigCore[] = {
    {"KConfig"},
    {"KConfigBase::WriteConfigFlags"},
    {"KConfigGroup"},
    {"KConfigSkeletonItem"},
    {"KCoreConfigSkeleton"},
    {NULL}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_KConfigGui_QtGui[] = {
    {"QColor"},
    {"QFont"},
    {"QKeySequence"},
    {"QList<QKeySequence>"},
    {"QWindow"},
    {NULL}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_KConfigGui_QtCore, sipImportedVirtErrorHandlers_KConfigGui_QtCore, NULL},
    {"PyKF5.KConfigCore", sipImportedTypes_KConfigGui_KConfigCore, NULL, NULL},
    {"PyQt5.QtGui", sipImportedTypes_KConfigGui_QtGui, NULL, NULL},
    {NULL, NULL, NULL, NULL}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_KConfigGui = {
    0,
    SIP_API_MINOR_NR,
    sipNameNr_PyKF5_KConfigGui,
    0,
    sipStrings_KConfigGui,
    importsTable,
    NULL,
    8,
    sipExportedTypes_KConfigGui,
    NULL,
    0,
    NULL,
    0,
    NULL,
    NULL,
    NULL,
    {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_KConfigGui;

sip_qt_metaobject_func sip_KConfigGui_qt_metaobject;
sip_qt_metacall_func sip_KConfigGui_qt_metacall;
sip_qt_metacast_func sip_KConfigGui_qt_metacast;


/* The Python module initialisation function. */
#if PY_MAJOR_VERSION >= 3
#define SIP_MODULE_ENTRY        PyInit_KConfigGui
#define SIP_MODULE_TYPE         PyObject *
#define SIP_MODULE_DISCARD(r)   Py_DECREF(r)
#define SIP_MODULE_RETURN(r)    return (r)
#else
#define SIP_MODULE_ENTRY        initKConfigGui
#define SIP_MODULE_TYPE         void
#define SIP_MODULE_DISCARD(r)
#define SIP_MODULE_RETURN(r)    return
#endif

#if defined(SIP_STATIC_MODULE)
extern "C" SIP_MODULE_TYPE SIP_MODULE_ENTRY()
#else
PyMODINIT_FUNC SIP_MODULE_ENTRY()
#endif
{
    static PyMethodDef sip_methods[] = {
        {0, 0, 0, 0}
    };

#if PY_MAJOR_VERSION >= 3
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyKF5.KConfigGui",
        NULL,
        -1,
        sip_methods,
        NULL,
        NULL,
        NULL,
        NULL
    };
#endif

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
#if PY_MAJOR_VERSION >= 3
    sipModule = PyModule_Create(&sip_module_def);
#elif PY_VERSION_HEX >= 0x02050000
    sipModule = Py_InitModule(sipName_PyKF5_KConfigGui, sip_methods);
#else
    sipModule = Py_InitModule(const_cast<char *>(sipName_PyKF5_KConfigGui), sip_methods);
#endif

    if (sipModule == NULL)
        SIP_MODULE_RETURN(NULL);

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
#if PY_VERSION_HEX >= 0x02050000
    sip_sipmod = PyImport_ImportModule(SIP_MODULE_NAME);
#else
    sip_sipmod = PyImport_ImportModule(const_cast<char *>(SIP_MODULE_NAME));
#endif

    if (sip_sipmod == NULL)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

#if defined(SIP_USE_PYCAPSULE)
    if (sip_capiobj == NULL || !PyCapsule_CheckExact(sip_capiobj))
#else
    if (sip_capiobj == NULL || !PyCObject_Check(sip_capiobj))
#endif
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }

#if defined(SIP_USE_PYCAPSULE)
    sipAPI_KConfigGui = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, SIP_MODULE_NAME "._C_API"));
#else
    sipAPI_KConfigGui = reinterpret_cast<const sipAPIDef *>(PyCObject_AsVoidPtr(sip_capiobj));
#endif

#if defined(SIP_USE_PYCAPSULE)
    if (sipAPI_KConfigGui == NULL)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }
#endif

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_KConfigGui,SIP_API_MAJOR_NR,SIP_API_MINOR_NR,0) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(0);
    }

    sip_KConfigGui_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_KConfigGui_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_KConfigGui_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_KConfigGui_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_KConfigGui,sipModuleDict) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(0);
    }

    SIP_MODULE_RETURN(sipModule);
}
