/*
 * Module code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <qobject.h>
#include <qstringlist.h>
#include <kconfigbase.h>
#include <qbytearray.h>
#include <kconfiggroup.h>
#include <kconfigbase.h>
#include <kconfig.h>
#include <qvariant.h>
#include <qmetaobject.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <kconfig.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>

/* Define the strings used by this module. */
const char sipStrings_KConfigCore[] = {
    'Q', 'L', 'i', 's', 't', '<', 'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'E', 'n', 'u', 'm', ':', ':', 'C', 'h', 'o', 'i', 'c', 'e', '>', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'E', 'n', 'u', 'm', ':', ':', 'C', 'h', 'o', 'i', 'c', 'e', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'S', 't', 'r', 'i', 'n', 'g', ':', ':', 'T', 'y', 'p', 'e', 0,
    'Q', 'H', 'a', 's', 'h', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'I', 't', 'e', 'm', '*', '>', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'U', 'L', 'o', 'n', 'g', 'L', 'o', 'n', 'g', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'P', 'a', 't', 'h', 'L', 'i', 's', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'L', 'o', 'n', 'g', 'L', 'o', 'n', 'g', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'I', 'n', 't', 'L', 'i', 's', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'U', 'r', 'l', 'L', 'i', 's', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'P', 'o', 'i', 'n', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'U', 'I', 'n', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'E', 'n', 'u', 'm', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'B', 'o', 'o', 'l', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'P', 'a', 't', 'h', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'B', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'F', 'l', 'a', 'g', 's', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'I', 'n', 't', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', ':', ':', 'I', 't', 'e', 'm', 'U', 'r', 'l', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'B', 'a', 's', 'e', ':', ':', 'W', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'F', 'l', 'a', 'g', 0,
    'Q', 'L', 'i', 's', 't', '<', 'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'I', 't', 'e', 'm', '*', '>', 0,
    'K', 'E', 'M', 'a', 'i', 'l', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'K', 'E', 'M', 'a', 'i', 'l', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    'i', 's', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'd', 'D', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'B', 'a', 's', 'e', ':', ':', 'A', 'c', 'c', 'e', 's', 's', 'M', 'o', 'd', 'e', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'M', 'o', 'd', 'u', 'l', 'e', 's', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'M', 'o', 'd', 'u', 'l', 'e', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'r', 'e', 'a', 'd', 'E', 'n', 't', 'r', 'y', 'U', 'n', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', 0,
    'i', 's', 'G', 'r', 'o', 'u', 'p', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 'I', 'm', 'p', 'l', 0,
    'r', 'e', 'p', 'a', 'r', 's', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'K', 'C', 'o', 'r', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'I', 't', 'e', 'm', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'h', 'a', 's', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', ':', ':', 'O', 'p', 'e', 'n', 'F', 'l', 'a', 'g', 's', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'S', 't', 'r', 'i', 'n', 'g', 'L', 'i', 's', 't', 0,
    'w', 'r', 'i', 't', 'e', 'X', 'd', 'g', 'L', 'i', 's', 't', 'E', 'n', 't', 'r', 'y', 0,
    's', 'e', 't', 'M', 'a', 'i', 'n', 'C', 'o', 'n', 'f', 'i', 'g', 'N', 'a', 'm', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', ':', ':', 'O', 'p', 'e', 'n', 'F', 'l', 'a', 'g', 0,
    'i', 's', 'S', 'i', 'g', 'n', 'a', 'l', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    's', 'e', 'n', 'd', 'e', 'r', 'S', 'i', 'g', 'n', 'a', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    'P', 'y', 'K', 'F', '5', '.', 'K', 'C', 'o', 'n', 'f', 'i', 'g', 'C', 'o', 'r', 'e', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'U', 'L', 'o', 'n', 'g', 'L', 'o', 'n', 'g', 0,
    'r', 'e', 'a', 'd', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'i', 's', 'E', 'n', 't', 'r', 'y', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 0,
    'r', 'e', 'a', 'd', 'X', 'd', 'g', 'L', 'i', 's', 't', 'E', 'n', 't', 'r', 'y', 0,
    'i', 's', 'G', 'r', 'o', 'u', 'p', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 0,
    'a', 'd', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 'S', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'i', 's', 'C', 'o', 'n', 'f', 'i', 'g', 'W', 'r', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'K', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'C', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'C', 'h', 'e', 'c', 'k', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'M', 'B', 'X', 'T', 'y', 'p', 'e', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'L', 'o', 'n', 'g', 'L', 'o', 'n', 'g', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'r', 'e', 'a', 'd', 'G', 'e', 'n', 'e', 'r', 'i', 'c', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'v', 'e', 'r', 't', 'T', 'o', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'G', 'r', 'o', 'u', 'p', 'I', 'm', 'p', 'l', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'L', 'o', 'g', 'i', 'n', 0,
    'R', 'e', 'p', 'l', 'y', 'T', 'o', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'C', 'l', 'i', 'e', 'n', 't', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 0,
    'K', 'E', 'M', 'a', 'i', 'l', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'u', 's', 'r', 'W', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'u', 's', 'r', 'S', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'u', 's', 'r', 'U', 's', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'I', 'n', 't', 'L', 'i', 's', 't', 0,
    'h', 'a', 's', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'w', 'r', 'i', 't', 'e', 'P', 'a', 't', 'h', 'E', 'n', 't', 'r', 'y', 0,
    's', 'e', 't', 'F', 'o', 'r', 'c', 'e', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'I', 'n', 'c', 'l', 'u', 'd', 'e', 'G', 'l', 'o', 'b', 'a', 'l', 's', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'L', 'o', 'g', 'i', 'n', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'P', 'a', 's', 's', 0,
    'C', 'l', 'i', 'e', 'n', 't', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'u', 's', 'r', 'R', 'e', 'a', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'U', 'I', 'n', 't', '6', '4', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'K', 'S', 'h', 'a', 'r', 'e', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'h', 'a', 's', 'D', 'e', 'v', 'i', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'a', 'd', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'i', 's', 'D', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 0,
    'r', 'e', 'a', 'd', 'P', 'a', 't', 'h', 'E', 'n', 't', 'r', 'y', 0,
    'C', 'a', 's', 'c', 'a', 'd', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'P', 'a', 's', 's', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 'T', 'L', 'S', 0,
    'O', 'r', 'g', 'a', 'n', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'E', 'm', 'a', 'i', 'l', 'A', 'd', 'd', 'r', 'e', 's', 's', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'P', 'o', 'i', 'n', 't', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'I', 'n', 't', '6', '4', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'W', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'd', 'e', 's', 'k', 't', 'o', 'p', 'G', 'r', 'o', 'u', 'p', 0,
    'K', 'D', 'e', 's', 'k', 't', 'o', 'p', 'F', 'i', 'l', 'e', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'G', 'r', 'o', 'u', 'p', 0,
    'v', 'i', 'r', 't', 'u', 'a', 'l', '_', 'h', 'o', 'o', 'k', 0,
    'h', 'a', 's', 'G', 'r', 'o', 'u', 'p', 'I', 'm', 'p', 'l', 0,
    'r', 'e', 'a', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'S', 'i', 'm', 'p', 'l', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 'T', 'L', 'S', 0,
    'u', 's', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'R', 'e', 'c', 't', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'U', 'I', 'n', 't', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'B', 'o', 'o', 'l', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 's', 0,
    's', 'e', 't', 'M', 'a', 'x', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'w', 'a', 'p', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'r', 'e', 'a', 'd', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'w', 'r', 'i', 't', 'e', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'r', 'e', 'a', 'd', 'D', 'o', 'c', 'P', 'a', 't', 'h', 0,
    'h', 'a', 's', 'L', 'i', 'n', 'k', 'T', 'y', 'p', 'e', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'r', 'e', 'a', 'd', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'r', 'e', 'a', 'd', 'C', 'o', 'm', 'm', 'e', 'n', 't', 0,
    'l', 'o', 'c', 'a', 't', 'e', 'L', 'o', 'c', 'a', 'l', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'E', 'n', 't', 'r', 'y', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'G', 'r', 'o', 'u', 'p', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'G', 'r', 'o', 'u', 'p', 0,
    'f', 'o', 'r', 'c', 'e', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'i', 's', 'I', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', 0,
    'c', 'h', 'e', 'c', 'k', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'm', 'a', 'r', 'k', 'A', 's', 'C', 'l', 'e', 'a', 'n', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 'B', 'a', 's', 'e', 0,
    'K', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    'g', 'e', 't', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'P', 'r', 'o', 'f', 'i', 'l', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 't', 'e', 'm', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 't', 'e', 'm', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 'I', 'n', 't', 0,
    'r', 'e', 'a', 'd', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    's', 'e', 't', 'T', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    'r', 'e', 'a', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'h', 'a', 's', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'w', 'r', 'i', 't', 'e', 'E', 'n', 't', 'r', 'y', 0,
    'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 0,
    'a', 'c', 'c', 'e', 's', 's', 'M', 'o', 'd', 'e', 0,
    'F', 'u', 'l', 'l', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'O', 'u', 't', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'w', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'n', 'o', 'D', 'i', 's', 'p', 'l', 'a', 'y', 0,
    'r', 'e', 'a', 'd', 'E', 'n', 't', 'r', 'y', 0,
    'L', 'o', 'c', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'g', 'r', 'o', 'u', 'p', 'I', 'm', 'p', 'l', 0,
    'g', 'r', 'o', 'u', 'p', 'L', 'i', 's', 't', 0,
    'o', 'p', 'e', 'n', 'F', 'l', 'a', 'g', 's', 0,
    'N', 'o', 'G', 'l', 'o', 'b', 'a', 'l', 's', 0,
    'N', 'o', 'C', 'a', 's', 'c', 'a', 'd', 'e', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 0,
    'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    's', 'o', 'r', 't', 'O', 'r', 'd', 'e', 'r', 0,
    'r', 'e', 'c', 'e', 'i', 'v', 'e', 'r', 's', 0,
    'R', 'e', 'a', 'd', 'W', 'r', 'i', 't', 'e', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'f', 'i', 'l', 'e', 's', 0,
    'I', 'n', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'R', 'e', 'a', 'l', 'N', 'a', 'm', 'e', 0,
    'f', 'i', 'n', 'd', 'I', 't', 'e', 'm', 0,
    'c', 'h', 'o', 'i', 'c', 'e', 's', '2', 0,
    'm', 'a', 'x', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'i', 'n', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 0,
    's', 'e', 't', 'G', 'r', 'o', 'u', 'p', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'r', 'e', 'a', 'd', 'P', 'a', 't', 'h', 0,
    'r', 'e', 'a', 'd', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'a', 'd', 'I', 'c', 'o', 'n', 0,
    'r', 'e', 'a', 'd', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'p', 'a', 'r', 'e', 'n', 't', 0,
    'N', 'o', 'A', 'c', 'c', 'e', 's', 's', 0,
    'h', 'a', 's', 'G', 'r', 'o', 'u', 'p', 0,
    'e', 'n', 't', 'r', 'y', 'M', 'a', 'p', 0,
    'n', 'a', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    'u', 's', 'r', 'S', 'a', 'v', 'e', 0,
    'u', 's', 'r', 'R', 'e', 'a', 'd', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 0,
    'c', 'h', 'o', 'i', 'c', 'e', 's', 0,
    'i', 's', 'E', 'q', 'u', 'a', 'l', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    't', 'r', 'y', 'E', 'x', 'e', 'c', 0,
    'r', 'e', 'a', 'd', 'U', 'r', 'l', 0,
    'k', 'e', 'y', 'L', 'i', 's', 't', 0,
    'i', 's', 'D', 'i', 'r', 't', 'y', 0,
    'K', 'C', 'o', 'n', 'f', 'i', 'g', 0,
    'f', 'i', 'l', 't', 'e', 'r', 's', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    'h', 'a', 's', 'K', 'e', 'y', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 0,
    'c', 'o', 'p', 'y', 'T', 'o', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 0,
    's', 'e', 'n', 'd', 'e', 'r', 0,
    'v', 'a', 'l', 'u', 'e', '9', 0,
    'v', 'a', 'l', 'u', 'e', '8', 0,
    'v', 'a', 'l', 'u', 'e', '7', 0,
    'v', 'a', 'l', 'u', 'e', '6', 0,
    'v', 'a', 'l', 'u', 'e', '5', 0,
    'v', 'a', 'l', 'u', 'e', '4', 0,
    'v', 'a', 'l', 'u', 'e', '3', 0,
    'v', 'a', 'l', 'u', 'e', '2', 0,
    'v', 'a', 'l', 'u', 'e', '1', 0,
    'v', 'a', 'l', 'u', 'e', '0', 0,
    's', 'e', 't', 'K', 'e', 'y', 0,
    's', 'y', 'm', 'b', 'o', 'l', 0,
    's', 'u', 'f', 'f', 'i', 'x', 0,
    'p', 'r', 'e', 'f', 'i', 'x', 0,
    'e', 'x', 'i', 's', 't', 's', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'O', 'T', 'H', 'E', 'R', 0,
    'i', 't', 'e', 'm', 's', 0,
    'l', 'a', 'b', 'e', 'l', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'm', 's', 'e', 'c', 's', 0,
    'g', 'r', 'o', 'u', 'p', 0,
    'S', 'M', 'T', 'P', 0,
    'P', 'O', 'P', '3', 0,
    's', 'a', 'v', 'e', 0,
    's', 'y', 'n', 'c', 0,
    'l', 'o', 'a', 'd', 0,
    'r', 'e', 'a', 'd', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'b', 'a', 's', 'e', 0,
    'f', 'r', 'o', 'm', 0,
    's', 'o', 'r', 't', 0,
    'k', 'e', 'y', 0,
};

bool sipVH_KConfigCore_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_KConfigCore_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "D", a0, sipType_QEvent, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_KConfigCore_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "DD", a0, sipType_QObject, NULL, a1, sipType_QEvent, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_KConfigCore_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, NULL);
}

void sipVH_KConfigCore_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, NULL);
}

void sipVH_KConfigCore_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, NULL);
}

void sipVH_KConfigCore_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QMetaMethod(a0), sipType_QMetaMethod, NULL);
}

 ::QVariant sipVH_KConfigCore_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_KConfigCore_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QVariant& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "N", new  ::QVariant(a0), sipType_QVariant, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_KConfigCore_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QVariant& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QVariant(a0), sipType_QVariant, NULL);
}

void sipVH_KConfigCore_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::KConfig*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_KConfig, NULL);
}

const  ::KConfigGroup sipVH_KConfigCore_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QByteArray& a0)
{
     ::KConfigGroup sipRes;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "N", new  ::QByteArray(a0), sipType_QByteArray, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_KConfigGroup, &sipRes);

    return sipRes;
}

void sipVH_KConfigCore_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0,void*a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iV", a0, a1);
}

void sipVH_KConfigCore_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QByteArray& a0, ::KConfigBase::WriteConfigFlags a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new  ::QByteArray(a0), sipType_QByteArray, NULL, new  ::KConfigBase::WriteConfigFlags(a1), sipType_KConfigBase_WriteConfigFlags, NULL);
}

 ::KConfigGroup sipVH_KConfigCore_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QByteArray& a0)
{
     ::KConfigGroup sipRes;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "N", new  ::QByteArray(a0), sipType_QByteArray, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_KConfigGroup, &sipRes);

    return sipRes;
}

bool sipVH_KConfigCore_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QByteArray& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "N", new  ::QByteArray(a0), sipType_QByteArray, NULL);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::KConfigBase::AccessMode sipVH_KConfigCore_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::KConfigBase::AccessMode sipRes = ( ::KConfigBase::AccessMode)0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_KConfigBase_AccessMode, &sipRes);

    return sipRes;
}

void sipVH_KConfigCore_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_KConfigCore_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QStringList sipVH_KConfigCore_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(0, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KEMailSettings__Extension, {0}, 0}, sipNameNr_Extension, 35, NULL},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KEMailSettings__Setting, {0}, 0}, sipNameNr_Setting, 35, NULL},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KCoreConfigSkeleton__ItemString__Type, {0}, 0}, sipNameNr_Type, 27, NULL},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KConfigBase__AccessMode, {0}, 0}, sipNameNr_AccessMode, 5, NULL},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KConfigBase__WriteConfigFlag, {0}, 0}, sipNameNr_WriteConfigFlag, 5, NULL},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_KConfig__OpenFlag, {0}, 0}, sipNameNr_OpenFlag, 2, NULL},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_KConfigCore[] = {
    &sipTypeDef_KConfigCore_ConversionCheck.ctd_base,
    &sipTypeDef_KConfigCore_KAuthorized.ctd_base,
    &sipTypeDef_KConfigCore_KConfig.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_KConfigCore_KConfig_OpenFlags.ctd_base,
    &sipTypeDef_KConfigCore_KConfigBase.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_KConfigCore_KConfigBase_WriteConfigFlags.ctd_base,
    &sipTypeDef_KConfigCore_KConfigGroup.ctd_base,
    &sipTypeDef_KConfigCore_KConfigSkeletonItem.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemBool.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemDateTime.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemDouble.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemEnum.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemEnum_Choice.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemInt.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemIntList.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemLongLong.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemPassword.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemPath.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemPathList.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemPoint.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemProperty.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemRect.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemSize.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemString.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemStringList.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemUInt.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemULongLong.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemUrl.ctd_base,
    &sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemUrlList.ctd_base,
    &sipTypeDef_KConfigCore_KDesktopFile.ctd_base,
    &sipTypeDef_KConfigCore_KEMailSettings.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_KConfigCore_KSharedConfig.ctd_base,
    &sipTypeDef_KConfigCore_QHash_0100QString_0101KConfigSkeletonItem.mtd_base,
    &sipTypeDef_KConfigCore_QList_0101KConfigSkeletonItem.mtd_base,
    &sipTypeDef_KConfigCore_QList_0100KCoreConfigSkeleton_ItemEnum_Choice.mtd_base,
    &sipTypeDef_KConfigCore_QMap_0100QString_0100QString.mtd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"KConfigSkeletonItem::Dict", "QHash<QString,KConfigSkeletonItem*>"},
    {"KConfigSkeletonItem::List", "QList<KConfigSkeletonItem*>"},
    {"KCoreConfigSkeleton::ItemEnum::Choice2", "KCoreConfigSkeleton::ItemEnum::Choice"},
    {"KCoreConfigSkeleton::ItemInt64", "KCoreConfigSkeleton::ItemLongLong"},
    {"KCoreConfigSkeleton::ItemUInt64", "KCoreConfigSkeleton::ItemULongLong"},
    {"KSharedConfig::Ptr", "QExplicitlySharedDataPointer<KSharedConfig>"},
    {"KSharedConfigPtr", "QExplicitlySharedDataPointer<KSharedConfig>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_KConfigCore_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QDateTime"},
    {"QEvent"},
    {"QList<QUrl>"},
    {"QList<QVariant>"},
    {"QList<int>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QRect"},
    {"QSize"},
    {"QStandardPaths::StandardLocation"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {NULL}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_KConfigCore_QtCore[] = {
    {"PyQt5"},
    {NULL}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_KConfigCore_QtCore, sipImportedVirtErrorHandlers_KConfigCore_QtCore, NULL},
    {NULL, NULL, NULL, NULL}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_KConfigCore = {
    0,
    SIP_API_MINOR_NR,
    sipNameNr_PyKF5_KConfigCore,
    0,
    sipStrings_KConfigCore,
    importsTable,
    NULL,
    43,
    sipExportedTypes_KConfigCore,
    NULL,
    0,
    NULL,
    7,
    typedefsTable,
    NULL,
    NULL,
    {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL},
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL,
    NULL
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_KConfigCore;

sip_qt_metaobject_func sip_KConfigCore_qt_metaobject;
sip_qt_metacall_func sip_KConfigCore_qt_metacall;
sip_qt_metacast_func sip_KConfigCore_qt_metacast;


/* The Python module initialisation function. */
#if PY_MAJOR_VERSION >= 3
#define SIP_MODULE_ENTRY        PyInit_KConfigCore
#define SIP_MODULE_TYPE         PyObject *
#define SIP_MODULE_DISCARD(r)   Py_DECREF(r)
#define SIP_MODULE_RETURN(r)    return (r)
#else
#define SIP_MODULE_ENTRY        initKConfigCore
#define SIP_MODULE_TYPE         void
#define SIP_MODULE_DISCARD(r)
#define SIP_MODULE_RETURN(r)    return
#endif

#if defined(SIP_STATIC_MODULE)
extern "C" SIP_MODULE_TYPE SIP_MODULE_ENTRY()
#else
PyMODINIT_FUNC SIP_MODULE_ENTRY()
#endif
{
    static PyMethodDef sip_methods[] = {
        {0, 0, 0, 0}
    };

#if PY_MAJOR_VERSION >= 3
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyKF5.KConfigCore",
        NULL,
        -1,
        sip_methods,
        NULL,
        NULL,
        NULL,
        NULL
    };
#endif

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
#if PY_MAJOR_VERSION >= 3
    sipModule = PyModule_Create(&sip_module_def);
#elif PY_VERSION_HEX >= 0x02050000
    sipModule = Py_InitModule(sipName_PyKF5_KConfigCore, sip_methods);
#else
    sipModule = Py_InitModule(const_cast<char *>(sipName_PyKF5_KConfigCore), sip_methods);
#endif

    if (sipModule == NULL)
        SIP_MODULE_RETURN(NULL);

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
#if PY_VERSION_HEX >= 0x02050000
    sip_sipmod = PyImport_ImportModule(SIP_MODULE_NAME);
#else
    sip_sipmod = PyImport_ImportModule(const_cast<char *>(SIP_MODULE_NAME));
#endif

    if (sip_sipmod == NULL)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

#if defined(SIP_USE_PYCAPSULE)
    if (sip_capiobj == NULL || !PyCapsule_CheckExact(sip_capiobj))
#else
    if (sip_capiobj == NULL || !PyCObject_Check(sip_capiobj))
#endif
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }

#if defined(SIP_USE_PYCAPSULE)
    sipAPI_KConfigCore = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, SIP_MODULE_NAME "._C_API"));
#else
    sipAPI_KConfigCore = reinterpret_cast<const sipAPIDef *>(PyCObject_AsVoidPtr(sip_capiobj));
#endif

#if defined(SIP_USE_PYCAPSULE)
    if (sipAPI_KConfigCore == NULL)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(NULL);
    }
#endif

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_KConfigCore,SIP_API_MAJOR_NR,SIP_API_MINOR_NR,0) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(0);
    }

    sip_KConfigCore_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_KConfigCore_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_KConfigCore_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_KConfigCore_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_KConfigCore,sipModuleDict) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(0);
    }

    SIP_MODULE_RETURN(sipModule);
}
