/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigGui.h"

#include <kwindowconfig.h>

#include <qwindow.h>
#include <kconfiggroup.h>
#include <kconfigbase.h>


extern "C" {static PyObject *meth_KWindowConfig_restoreWindowSize(PyObject *, PyObject *);}
static PyObject *meth_KWindowConfig_restoreWindowSize(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::QWindow* a0;
        const  ::KConfigGroup* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J9", sipType_QWindow, &a0, sipType_KConfigGroup, &a1))
        {
             ::KWindowConfig::restoreWindowSize(a0,*a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_restoreWindowSize, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KWindowConfig_saveWindowSize(PyObject *, PyObject *);}
static PyObject *meth_KWindowConfig_saveWindowSize(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QWindow* a0;
         ::KConfigGroup* a1;
         ::KConfigBase::WriteConfigFlags a2def = KConfigBase::Normal;
         ::KConfigBase::WriteConfigFlags* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8J9|J1", sipType_QWindow, &a0, sipType_KConfigGroup, &a1, sipType_KConfigBase_WriteConfigFlags, &a2, &a2State))
        {
             ::KWindowConfig::saveWindowSize(a0,*a1,*a2);
            sipReleaseType(a2,sipType_KConfigBase_WriteConfigFlags,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_saveWindowSize, NULL);

    return NULL;
}


static PyMethodDef methods_KWindowConfig[] = {
    {SIP_MLNAME_CAST(sipName_restoreWindowSize), meth_KWindowConfig_restoreWindowSize, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_saveWindowSize), meth_KWindowConfig_saveWindowSize, METH_VARARGS, NULL}
};


static pyqt5ClassPluginDef plugin_KWindowConfig = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigGui_KWindowConfig = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_NAMESPACE,
        sipNameNr_KWindowConfig,
        {0},
        &plugin_KWindowConfig
    },
    {
        sipNameNr_KWindowConfig,
        {0, 0, 1},
        2, methods_KWindowConfig,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    0,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
