/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kdesktopfile.h>

#include <qstandardpaths.h>
#include <qstring.h>
#include <qstringlist.h>
#include <kconfiggroup.h>
#include <qbytearray.h>
#include <kconfigbase.h>
#include <qmap.h>
#include <kconfigbase.h>
#include <kconfig.h>


class sipKDesktopFile : public  ::KDesktopFile
{
public:
    sipKDesktopFile( ::QStandardPaths::StandardLocation,const  ::QString&);
    sipKDesktopFile(const  ::QString&);
    virtual ~sipKDesktopFile();

    /*
     * There is a public method for every protected method visible from
     * this class.
     */
    bool sipProtectVirt_hasGroupImpl(bool,const  ::QByteArray&) const;
     ::KConfigGroup sipProtectVirt_groupImpl(bool,const  ::QByteArray&);
    void sipProtectVirt_deleteGroupImpl(bool,const  ::QByteArray&, ::KConfigBase::WriteConfigFlags);
    bool sipProtectVirt_isGroupImmutableImpl(bool,const  ::QByteArray&) const;
    void sipProtectVirt_virtual_hook(bool,int,void*);

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void virtual_hook(int,void*);
    bool isGroupImmutableImpl(const  ::QByteArray&) const;
    void deleteGroupImpl(const  ::QByteArray&, ::KConfigBase::WriteConfigFlags);
     ::KConfigGroup groupImpl(const  ::QByteArray&);
    bool hasGroupImpl(const  ::QByteArray&) const;
    bool isImmutable() const;
     ::KConfigBase::AccessMode accessMode() const;
    void markAsClean();
    bool sync();
     ::QStringList groupList() const;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipKDesktopFile(const sipKDesktopFile &);
    sipKDesktopFile &operator = (const sipKDesktopFile &);

    char sipPyMethods[10];
};

sipKDesktopFile::sipKDesktopFile( ::QStandardPaths::StandardLocation a0,const  ::QString& a1):  ::KDesktopFile(a0,a1), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKDesktopFile::sipKDesktopFile(const  ::QString& a0):  ::KDesktopFile(a0), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKDesktopFile::~sipKDesktopFile()
{
    sipInstanceDestroyed(sipPySelf);
}

void sipKDesktopFile::virtual_hook(int a0,void*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,NULL,sipName_virtual_hook);

    if (!sipMeth)
    {
         ::KDesktopFile::virtual_hook(a0,a1);
        return;
    }

    extern void sipVH_KConfigCore_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int,void*);

    sipVH_KConfigCore_7(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipKDesktopFile::isGroupImmutableImpl(const  ::QByteArray& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,NULL,sipName_isGroupImmutableImpl);

    if (!sipMeth)
        return  ::KDesktopFile::isGroupImmutableImpl(a0);

    extern bool sipVH_KConfigCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QByteArray&);

    return sipVH_KConfigCore_4(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKDesktopFile::deleteGroupImpl(const  ::QByteArray& a0, ::KConfigBase::WriteConfigFlags a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,NULL,sipName_deleteGroupImpl);

    if (!sipMeth)
    {
         ::KDesktopFile::deleteGroupImpl(a0,a1);
        return;
    }

    extern void sipVH_KConfigCore_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QByteArray&, ::KConfigBase::WriteConfigFlags);

    sipVH_KConfigCore_6(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

 ::KConfigGroup sipKDesktopFile::groupImpl(const  ::QByteArray& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,NULL,sipName_groupImpl);

    if (!sipMeth)
        return  ::KDesktopFile::groupImpl(a0);

    extern  ::KConfigGroup sipVH_KConfigCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QByteArray&);

    return sipVH_KConfigCore_5(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKDesktopFile::hasGroupImpl(const  ::QByteArray& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,NULL,sipName_hasGroupImpl);

    if (!sipMeth)
        return  ::KDesktopFile::hasGroupImpl(a0);

    extern bool sipVH_KConfigCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QByteArray&);

    return sipVH_KConfigCore_4(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKDesktopFile::isImmutable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,NULL,sipName_isImmutable);

    if (!sipMeth)
        return  ::KDesktopFile::isImmutable();

    extern bool sipVH_KConfigCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_1(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::KConfigBase::AccessMode sipKDesktopFile::accessMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[6]),sipPySelf,NULL,sipName_accessMode);

    if (!sipMeth)
        return  ::KDesktopFile::accessMode();

    extern  ::KConfigBase::AccessMode sipVH_KConfigCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_3(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKDesktopFile::markAsClean()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,NULL,sipName_markAsClean);

    if (!sipMeth)
    {
         ::KDesktopFile::markAsClean();
        return;
    }

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKDesktopFile::sync()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,NULL,sipName_sync);

    if (!sipMeth)
        return  ::KDesktopFile::sync();

    extern bool sipVH_KConfigCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_1(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QStringList sipKDesktopFile::groupList() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[9]),sipPySelf,NULL,sipName_groupList);

    if (!sipMeth)
        return  ::KDesktopFile::groupList();

    extern  ::QStringList sipVH_KConfigCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_0(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKDesktopFile::sipProtectVirt_hasGroupImpl(bool sipSelfWasArg,const  ::QByteArray& a0) const
{
    return (sipSelfWasArg ?  ::KConfig::hasGroupImpl(a0) : hasGroupImpl(a0));
}

 ::KConfigGroup sipKDesktopFile::sipProtectVirt_groupImpl(bool sipSelfWasArg,const  ::QByteArray& a0)
{
    return (sipSelfWasArg ?  ::KConfig::groupImpl(a0) : groupImpl(a0));
}

void sipKDesktopFile::sipProtectVirt_deleteGroupImpl(bool sipSelfWasArg,const  ::QByteArray& a0, ::KConfigBase::WriteConfigFlags a1)
{
    (sipSelfWasArg ?  ::KConfig::deleteGroupImpl(a0,a1) : deleteGroupImpl(a0,a1));
}

bool sipKDesktopFile::sipProtectVirt_isGroupImmutableImpl(bool sipSelfWasArg,const  ::QByteArray& a0) const
{
    return (sipSelfWasArg ?  ::KConfig::isGroupImmutableImpl(a0) : isGroupImmutableImpl(a0));
}

void sipKDesktopFile::sipProtectVirt_virtual_hook(bool sipSelfWasArg,int a0,void*a1)
{
    (sipSelfWasArg ?  ::KConfig::virtual_hook(a0,a1) : virtual_hook(a0,a1));
}


extern "C" {static PyObject *meth_KDesktopFile_hasGroupImpl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_hasGroupImpl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const sipKDesktopFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_hasGroupImpl(sipSelfWasArg,*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_hasGroupImpl, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_groupImpl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_groupImpl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        sipKDesktopFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
             ::KConfigGroup*sipRes;

            sipRes = new  ::KConfigGroup(sipCpp->sipProtectVirt_groupImpl(sipSelfWasArg,*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return sipConvertFromNewType(sipRes,sipType_KConfigGroup,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_groupImpl, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_deleteGroupImpl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_deleteGroupImpl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QByteArray* a0;
        int a0State = 0;
         ::KConfigBase::WriteConfigFlags a1def = KConfigBase::Normal;
         ::KConfigBase::WriteConfigFlags* a1 = &a1def;
        int a1State = 0;
        sipKDesktopFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ1|J1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_KConfigBase_WriteConfigFlags, &a1, &a1State))
        {
            sipCpp->sipProtectVirt_deleteGroupImpl(sipSelfWasArg,*a0,*a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);
            sipReleaseType(a1,sipType_KConfigBase_WriteConfigFlags,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_deleteGroupImpl, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_isGroupImmutableImpl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_isGroupImmutableImpl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QByteArray* a0;
        int a0State = 0;
        const sipKDesktopFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_isGroupImmutableImpl(sipSelfWasArg,*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0),sipType_QByteArray,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_isGroupImmutableImpl, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_virtual_hook(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_virtual_hook(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        void* a1;
        sipKDesktopFile *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "Biv", &sipSelf, sipType_KDesktopFile, &sipCpp, &a0, &a1))
        {
            sipCpp->sipProtectVirt_virtual_hook(sipSelfWasArg,a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_virtual_hook, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_isDesktopFile(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_isDesktopFile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KDesktopFile::isDesktopFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_isDesktopFile, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_isAuthorizedDesktopFile(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_isAuthorizedDesktopFile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes =  ::KDesktopFile::isAuthorizedDesktopFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_isAuthorizedDesktopFile, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_locateLocal(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_locateLocal(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString,&a0, &a0State))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::KDesktopFile::locateLocal(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_locateLocal, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_desktopGroup(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_desktopGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::KConfigGroup*sipRes;

            sipRes = new  ::KConfigGroup(sipCpp->desktopGroup());

            return sipConvertFromNewType(sipRes,sipType_KConfigGroup,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_desktopGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readType(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readType());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readType, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readIcon(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readIcon());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readIcon, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readName(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readName());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readName, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readComment(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readComment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readComment());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readComment, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readGenericName(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readGenericName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readGenericName());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readGenericName, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readPath(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readPath());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readPath, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readDevice(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readDevice());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readDevice, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readUrl(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readUrl());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readUrl, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readActions(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList(sipCpp->readActions());

            return sipConvertFromNewType(sipRes,sipType_QStringList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readActions, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readMimeTypes(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readMimeTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList(sipCpp->readMimeTypes());

            return sipConvertFromNewType(sipRes,sipType_QStringList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readMimeTypes, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_actionGroup(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_actionGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QString,&a0, &a0State))
        {
             ::KConfigGroup*sipRes;

            sipRes = new  ::KConfigGroup(sipCpp->actionGroup(*a0));
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromNewType(sipRes,sipType_KConfigGroup,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_actionGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_hasActionGroup(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_hasActionGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasActionGroup(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_hasActionGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_hasLinkType(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_hasLinkType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasLinkType();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_hasLinkType, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_hasApplicationType(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_hasApplicationType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasApplicationType();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_hasApplicationType, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_hasDeviceType(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_hasDeviceType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasDeviceType();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_hasDeviceType, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_tryExec(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_tryExec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->tryExec();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_tryExec, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_readDocPath(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_readDocPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->readDocPath());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_readDocPath, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_sortOrder(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_sortOrder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QStringList*sipRes;

            sipRes = new  ::QStringList(sipCpp->sortOrder());

            return sipConvertFromNewType(sipRes,sipType_QStringList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_sortOrder, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_noDisplay(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_noDisplay(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->noDisplay();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_noDisplay, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_copyTo(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_copyTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KDesktopFile, &sipCpp, sipType_QString,&a0, &a0State))
        {
             ::KDesktopFile*sipRes;

            sipRes = sipCpp->copyTo(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromType(sipRes,sipType_KDesktopFile,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_copyTo, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_fileName(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->fileName());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_fileName, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KDesktopFile_resource(PyObject *, PyObject *);}
static PyObject *meth_KDesktopFile_resource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KDesktopFile *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KDesktopFile, &sipCpp))
        {
             ::QStandardPaths::StandardLocation sipRes;

            sipRes = sipCpp->resource();

            return sipConvertFromEnum(sipRes,sipType_QStandardPaths_StandardLocation);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KDesktopFile, sipName_resource, NULL);

    return NULL;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_KDesktopFile(void *, const sipTypeDef *);}
static void *cast_KDesktopFile(void *sipCppV, const sipTypeDef *targetType)
{
     ::KDesktopFile *sipCpp = reinterpret_cast< ::KDesktopFile *>(sipCppV);

    if (targetType == sipType_KConfig)
        return static_cast< ::KConfig *>(sipCpp);

    if (targetType == sipType_KConfigBase)
        return static_cast< ::KConfigBase *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_KDesktopFile(void *, int);}
static void release_KDesktopFile(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipKDesktopFile *>(sipCppV);
    else
        delete reinterpret_cast< ::KDesktopFile *>(sipCppV);
}


extern "C" {static void dealloc_KDesktopFile(sipSimpleWrapper *);}
static void dealloc_KDesktopFile(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipKDesktopFile *>(sipGetAddress(sipSelf))->sipPySelf = NULL;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_KDesktopFile(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_KDesktopFile(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KDesktopFile(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipKDesktopFile *sipCpp = 0;

    {
         ::QStandardPaths::StandardLocation a0;
        const  ::QString* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "EJ1", sipType_QStandardPaths_StandardLocation, &a0, sipType_QString,&a1, &a1State))
        {
            sipCpp = new sipKDesktopFile(a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const  ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "J1", sipType_QString,&a0, &a0State))
        {
            sipCpp = new sipKDesktopFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return NULL;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_KDesktopFile[] = {{2, 255, 1}};


static PyMethodDef methods_KDesktopFile[] = {
    {SIP_MLNAME_CAST(sipName_actionGroup), meth_KDesktopFile_actionGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_copyTo), meth_KDesktopFile_copyTo, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_deleteGroupImpl), (PyCFunction)meth_KDesktopFile_deleteGroupImpl, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_desktopGroup), meth_KDesktopFile_desktopGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_fileName), meth_KDesktopFile_fileName, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_groupImpl), (PyCFunction)meth_KDesktopFile_groupImpl, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_hasActionGroup), meth_KDesktopFile_hasActionGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_hasApplicationType), meth_KDesktopFile_hasApplicationType, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_hasDeviceType), meth_KDesktopFile_hasDeviceType, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_hasGroupImpl), (PyCFunction)meth_KDesktopFile_hasGroupImpl, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_hasLinkType), meth_KDesktopFile_hasLinkType, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isAuthorizedDesktopFile), meth_KDesktopFile_isAuthorizedDesktopFile, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isDesktopFile), meth_KDesktopFile_isDesktopFile, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isGroupImmutableImpl), (PyCFunction)meth_KDesktopFile_isGroupImmutableImpl, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_locateLocal), meth_KDesktopFile_locateLocal, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_noDisplay), meth_KDesktopFile_noDisplay, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readActions), meth_KDesktopFile_readActions, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readComment), meth_KDesktopFile_readComment, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readDevice), meth_KDesktopFile_readDevice, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readDocPath), meth_KDesktopFile_readDocPath, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readGenericName), meth_KDesktopFile_readGenericName, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readIcon), meth_KDesktopFile_readIcon, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readMimeTypes), meth_KDesktopFile_readMimeTypes, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readName), meth_KDesktopFile_readName, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readPath), meth_KDesktopFile_readPath, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readType), meth_KDesktopFile_readType, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readUrl), meth_KDesktopFile_readUrl, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_resource), meth_KDesktopFile_resource, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_sortOrder), meth_KDesktopFile_sortOrder, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_tryExec), meth_KDesktopFile_tryExec, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_virtual_hook), (PyCFunction)meth_KDesktopFile_virtual_hook, METH_VARARGS|METH_KEYWORDS, NULL}
};


static pyqt5ClassPluginDef plugin_KDesktopFile = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KDesktopFile = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KDesktopFile,
        {0},
        &plugin_KDesktopFile
    },
    {
        sipNameNr_KDesktopFile,
        {0, 0, 1},
        31, methods_KDesktopFile,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    supers_KDesktopFile,
    0,
    init_type_KDesktopFile,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KDesktopFile,
    0,
    0,
    0,
    release_KDesktopFile,
    cast_KDesktopFile,
    0,
    0,
    0,
    0,
    0,
    0
};
