/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>

#include <qstring.h>


/* Call the instance's destructor. */
extern "C" {static void release_KCoreConfigSkeleton_ItemEnum_Choice(void *, int);}
static void release_KCoreConfigSkeleton_ItemEnum_Choice(void *sipCppV, int)
{
    delete reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipCppV);
}


extern "C" {static void assign_KCoreConfigSkeleton_ItemEnum_Choice(void *, SIP_SSIZE_T, const void *);}
static void assign_KCoreConfigSkeleton_ItemEnum_Choice(void *sipDst, SIP_SSIZE_T sipDstIdx, const void *sipSrc)
{
    reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipDst)[sipDstIdx] = *reinterpret_cast<const  ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSrc);
}


extern "C" {static void *array_KCoreConfigSkeleton_ItemEnum_Choice(SIP_SSIZE_T);}
static void *array_KCoreConfigSkeleton_ItemEnum_Choice(SIP_SSIZE_T sipNrElem)
{
    return new  ::KCoreConfigSkeleton::ItemEnum::Choice[sipNrElem];
}


extern "C" {static void *copy_KCoreConfigSkeleton_ItemEnum_Choice(const void *, SIP_SSIZE_T);}
static void *copy_KCoreConfigSkeleton_ItemEnum_Choice(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::KCoreConfigSkeleton::ItemEnum::Choice(reinterpret_cast<const  ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_KCoreConfigSkeleton_ItemEnum_Choice(sipSimpleWrapper *);}
static void dealloc_KCoreConfigSkeleton_ItemEnum_Choice(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_KCoreConfigSkeleton_ItemEnum_Choice(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_KCoreConfigSkeleton_ItemEnum_Choice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KCoreConfigSkeleton_ItemEnum_Choice(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = 0;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, ""))
        {
            sipCpp = new  ::KCoreConfigSkeleton::ItemEnum::Choice();

            return sipCpp;
        }
    }

    {
        const  ::KCoreConfigSkeleton::ItemEnum::Choice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "J9", sipType_KCoreConfigSkeleton_ItemEnum_Choice, &a0))
        {
            sipCpp = new  ::KCoreConfigSkeleton::ItemEnum::Choice(*a0);

            return sipCpp;
        }
    }

    return NULL;
}


extern "C" {static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_label(void *, PyObject *, PyObject *);}
static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_label(void *sipSelf, PyObject *, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    sipVal = &sipCpp->label;

    return sipConvertFromType(sipVal, sipType_QString, NULL);
}


extern "C" {static int varset_KCoreConfigSkeleton_ItemEnum_Choice_label(void *, PyObject *, PyObject *);}
static int varset_KCoreConfigSkeleton_ItemEnum_Choice_label(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy,sipType_QString,NULL,SIP_NOT_NONE,&sipValState,&sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->label = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_name(void *, PyObject *, PyObject *);}
static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_name(void *sipSelf, PyObject *, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    sipVal = &sipCpp->name;

    return sipConvertFromType(sipVal, sipType_QString, NULL);
}


extern "C" {static int varset_KCoreConfigSkeleton_ItemEnum_Choice_name(void *, PyObject *, PyObject *);}
static int varset_KCoreConfigSkeleton_ItemEnum_Choice_name(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy,sipType_QString,NULL,SIP_NOT_NONE,&sipValState,&sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->name = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_toolTip(void *, PyObject *, PyObject *);}
static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_toolTip(void *sipSelf, PyObject *, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    sipVal = &sipCpp->toolTip;

    return sipConvertFromType(sipVal, sipType_QString, NULL);
}


extern "C" {static int varset_KCoreConfigSkeleton_ItemEnum_Choice_toolTip(void *, PyObject *, PyObject *);}
static int varset_KCoreConfigSkeleton_ItemEnum_Choice_toolTip(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy,sipType_QString,NULL,SIP_NOT_NONE,&sipValState,&sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->toolTip = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis(void *, PyObject *, PyObject *);}
static PyObject *varget_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis(void *sipSelf, PyObject *, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    sipVal = &sipCpp->whatsThis;

    return sipConvertFromType(sipVal, sipType_QString, NULL);
}


extern "C" {static int varset_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis(void *, PyObject *, PyObject *);}
static int varset_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis(void *sipSelf, PyObject *sipPy, PyObject *)
{
     ::QString*sipVal;
     ::KCoreConfigSkeleton::ItemEnum::Choice *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemEnum::Choice *>(sipSelf);

    int sipValState;
    int sipIsErr = 0;

    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy,sipType_QString,NULL,SIP_NOT_NONE,&sipValState,&sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->whatsThis = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}

sipVariableDef variables_KCoreConfigSkeleton_ItemEnum_Choice[] = {
    {InstanceVariable, sipName_label, (PyMethodDef *)varget_KCoreConfigSkeleton_ItemEnum_Choice_label, (PyMethodDef *)varset_KCoreConfigSkeleton_ItemEnum_Choice_label, NULL, NULL},
    {InstanceVariable, sipName_name, (PyMethodDef *)varget_KCoreConfigSkeleton_ItemEnum_Choice_name, (PyMethodDef *)varset_KCoreConfigSkeleton_ItemEnum_Choice_name, NULL, NULL},
    {InstanceVariable, sipName_toolTip, (PyMethodDef *)varget_KCoreConfigSkeleton_ItemEnum_Choice_toolTip, (PyMethodDef *)varset_KCoreConfigSkeleton_ItemEnum_Choice_toolTip, NULL, NULL},
    {InstanceVariable, sipName_whatsThis, (PyMethodDef *)varget_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis, (PyMethodDef *)varset_KCoreConfigSkeleton_ItemEnum_Choice_whatsThis, NULL, NULL},
};


static pyqt5ClassPluginDef plugin_KCoreConfigSkeleton_ItemEnum_Choice = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemEnum_Choice = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KCoreConfigSkeleton__ItemEnum__Choice,
        {0},
        &plugin_KCoreConfigSkeleton_ItemEnum_Choice
    },
    {
        sipNameNr_Choice,
        {15, 255, 0},
        0, 0,
        0, 0,
        4, variables_KCoreConfigSkeleton_ItemEnum_Choice,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    init_type_KCoreConfigSkeleton_ItemEnum_Choice,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KCoreConfigSkeleton_ItemEnum_Choice,
    assign_KCoreConfigSkeleton_ItemEnum_Choice,
    array_KCoreConfigSkeleton_ItemEnum_Choice,
    copy_KCoreConfigSkeleton_ItemEnum_Choice,
    release_KCoreConfigSkeleton_ItemEnum_Choice,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
