/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>

#include <qstring.h>
#include <qvariant.h>
#include <kconfig.h>
#include <kconfiggroup.h>


class sipKCoreConfigSkeleton_ItemPassword : public  ::KCoreConfigSkeleton::ItemPassword
{
public:
    sipKCoreConfigSkeleton_ItemPassword(const  ::QString&,const  ::QString&, ::QString&,const  ::QString&);
    virtual ~sipKCoreConfigSkeleton_ItemPassword();

    /*
     * There is a public method for every protected method visible from
     * this class.
     */
    void sipProtect_readImmutability(const  ::KConfigGroup&);

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void swapDefault();
    void setDefault();
     ::QVariant maxValue() const;
     ::QVariant minValue() const;
     ::QVariant property() const;
    bool isEqual(const  ::QVariant&) const;
    void setProperty(const  ::QVariant&);
    void readDefault( ::KConfig*);
    void writeConfig( ::KConfig*);
    void readConfig( ::KConfig*);

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipKCoreConfigSkeleton_ItemPassword(const sipKCoreConfigSkeleton_ItemPassword &);
    sipKCoreConfigSkeleton_ItemPassword &operator = (const sipKCoreConfigSkeleton_ItemPassword &);

    char sipPyMethods[10];
};

sipKCoreConfigSkeleton_ItemPassword::sipKCoreConfigSkeleton_ItemPassword(const  ::QString& a0,const  ::QString& a1, ::QString& a2,const  ::QString& a3):  ::KCoreConfigSkeleton::ItemPassword(a0,a1,a2,a3), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKCoreConfigSkeleton_ItemPassword::~sipKCoreConfigSkeleton_ItemPassword()
{
    sipInstanceDestroyed(sipPySelf);
}

void sipKCoreConfigSkeleton_ItemPassword::swapDefault()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,sipName_ItemPassword,sipName_swapDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKCoreConfigSkeleton_ItemPassword::setDefault()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,sipName_ItemPassword,sipName_setDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKCoreConfigSkeleton_ItemPassword::maxValue() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,NULL,sipName_maxValue);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::ItemPassword::maxValue();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKCoreConfigSkeleton_ItemPassword::minValue() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,NULL,sipName_minValue);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::ItemPassword::minValue();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKCoreConfigSkeleton_ItemPassword::property() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,NULL,sipName_property);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::ItemPassword::property();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKCoreConfigSkeleton_ItemPassword::isEqual(const  ::QVariant& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,NULL,sipName_isEqual);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::ItemPassword::isEqual(a0);

    extern bool sipVH_KConfigCore_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QVariant&);

    return sipVH_KConfigCore_11(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton_ItemPassword::setProperty(const  ::QVariant& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,NULL,sipName_setProperty);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::ItemPassword::setProperty(a0);
        return;
    }

    extern void sipVH_KConfigCore_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QVariant&);

    sipVH_KConfigCore_10(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton_ItemPassword::readDefault( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,sipName_ItemPassword,sipName_readDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton_ItemPassword::writeConfig( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,NULL,sipName_writeConfig);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::ItemPassword::writeConfig(a0);
        return;
    }

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton_ItemPassword::readConfig( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,NULL,sipName_readConfig);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::ItemPassword::readConfig(a0);
        return;
    }

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton_ItemPassword::sipProtect_readImmutability(const  ::KConfigGroup& a0)
{
     ::KConfigSkeletonItem::readImmutability(a0);
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_ItemPassword_readImmutability(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_ItemPassword_readImmutability(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigGroup* a0;
        sipKCoreConfigSkeleton_ItemPassword *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KCoreConfigSkeleton_ItemPassword, &sipCpp, sipType_KConfigGroup, &a0))
        {
            sipCpp->sipProtect_readImmutability(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_ItemPassword, sipName_readImmutability, NULL);

    return NULL;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_KCoreConfigSkeleton_ItemPassword(void *, const sipTypeDef *);}
static void *cast_KCoreConfigSkeleton_ItemPassword(void *sipCppV, const sipTypeDef *targetType)
{
     ::KCoreConfigSkeleton::ItemPassword *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton::ItemPassword *>(sipCppV);

    if (targetType == sipType_KCoreConfigSkeleton_ItemString)
        return static_cast< ::KCoreConfigSkeleton::ItemString *>(sipCpp);

    if (targetType == sipType_KConfigSkeletonItem)
        return static_cast< ::KConfigSkeletonItem *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_KCoreConfigSkeleton_ItemPassword(void *, int);}
static void release_KCoreConfigSkeleton_ItemPassword(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipKCoreConfigSkeleton_ItemPassword *>(sipCppV);
    else
        delete reinterpret_cast< ::KCoreConfigSkeleton::ItemPassword *>(sipCppV);
}


extern "C" {static void dealloc_KCoreConfigSkeleton_ItemPassword(sipSimpleWrapper *);}
static void dealloc_KCoreConfigSkeleton_ItemPassword(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipKCoreConfigSkeleton_ItemPassword *>(sipGetAddress(sipSelf))->sipPySelf = NULL;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_KCoreConfigSkeleton_ItemPassword(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_KCoreConfigSkeleton_ItemPassword(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KCoreConfigSkeleton_ItemPassword(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipKCoreConfigSkeleton_ItemPassword *sipCpp = 0;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QString* a1;
        int a1State = 0;
         ::QString* a2;
        int a2State = 0;
        const  ::QString& a3def = QLatin1String("");
        const  ::QString* a3 = &a3def;
        int a3State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "J1J1J1|J1", sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State, sipType_QString,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
            sipCpp = new sipKCoreConfigSkeleton_ItemPassword(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);
            sipReleaseType(a2,sipType_QString,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return NULL;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_KCoreConfigSkeleton_ItemPassword[] = {{27, 255, 1}};


static PyMethodDef methods_KCoreConfigSkeleton_ItemPassword[] = {
    {SIP_MLNAME_CAST(sipName_readImmutability), (PyCFunction)meth_KCoreConfigSkeleton_ItemPassword_readImmutability, METH_VARARGS|METH_KEYWORDS, NULL}
};


static pyqt5ClassPluginDef plugin_KCoreConfigSkeleton_ItemPassword = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KCoreConfigSkeleton_ItemPassword = {
    {
        -1,
        0,
        0,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KCoreConfigSkeleton__ItemPassword,
        {0},
        &plugin_KCoreConfigSkeleton_ItemPassword
    },
    {
        sipNameNr_ItemPassword,
        {11, 255, 0},
        1, methods_KCoreConfigSkeleton_ItemPassword,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    supers_KCoreConfigSkeleton_ItemPassword,
    0,
    init_type_KCoreConfigSkeleton_ItemPassword,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KCoreConfigSkeleton_ItemPassword,
    0,
    0,
    0,
    release_KCoreConfigSkeleton_ItemPassword,
    cast_KCoreConfigSkeleton_ItemPassword,
    0,
    0,
    0,
    0,
    0,
    0
};
