/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kcoreconfigskeleton.h>

#include <qstring.h>
#include <kconfiggroup.h>
#include <qvariant.h>
#include <kconfig.h>


class sipKConfigSkeletonItem : public  ::KConfigSkeletonItem
{
public:
    sipKConfigSkeletonItem(const  ::QString&,const  ::QString&);
    virtual ~sipKConfigSkeletonItem();

    /*
     * There is a public method for every protected method visible from
     * this class.
     */
    void sipProtect_readImmutability(const  ::KConfigGroup&);

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void swapDefault();
    void setDefault();
     ::QVariant maxValue() const;
     ::QVariant minValue() const;
     ::QVariant property() const;
    bool isEqual(const  ::QVariant&) const;
    void setProperty(const  ::QVariant&);
    void readDefault( ::KConfig*);
    void writeConfig( ::KConfig*);
    void readConfig( ::KConfig*);

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipKConfigSkeletonItem(const sipKConfigSkeletonItem &);
    sipKConfigSkeletonItem &operator = (const sipKConfigSkeletonItem &);

    char sipPyMethods[10];
};

sipKConfigSkeletonItem::sipKConfigSkeletonItem(const  ::QString& a0,const  ::QString& a1):  ::KConfigSkeletonItem(a0,a1), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKConfigSkeletonItem::~sipKConfigSkeletonItem()
{
    sipInstanceDestroyed(sipPySelf);
}

void sipKConfigSkeletonItem::swapDefault()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,sipName_KConfigSkeletonItem,sipName_swapDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKConfigSkeletonItem::setDefault()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,sipName_KConfigSkeletonItem,sipName_setDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKConfigSkeletonItem::maxValue() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,NULL,sipName_maxValue);

    if (!sipMeth)
        return  ::KConfigSkeletonItem::maxValue();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKConfigSkeletonItem::minValue() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,NULL,sipName_minValue);

    if (!sipMeth)
        return  ::KConfigSkeletonItem::minValue();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QVariant sipKConfigSkeletonItem::property() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,sipName_KConfigSkeletonItem,sipName_property);

    if (!sipMeth)
        return  ::QVariant();

    extern  ::QVariant sipVH_KConfigCore_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_12(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKConfigSkeletonItem::isEqual(const  ::QVariant& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,sipName_KConfigSkeletonItem,sipName_isEqual);

    if (!sipMeth)
        return 0;

    extern bool sipVH_KConfigCore_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QVariant&);

    return sipVH_KConfigCore_11(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeletonItem::setProperty(const  ::QVariant& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,sipName_KConfigSkeletonItem,sipName_setProperty);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QVariant&);

    sipVH_KConfigCore_10(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeletonItem::readDefault( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,sipName_KConfigSkeletonItem,sipName_readDefault);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeletonItem::writeConfig( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,sipName_KConfigSkeletonItem,sipName_writeConfig);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeletonItem::readConfig( ::KConfig*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,sipName_KConfigSkeletonItem,sipName_readConfig);

    if (!sipMeth)
        return;

    extern void sipVH_KConfigCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::KConfig*);

    sipVH_KConfigCore_9(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeletonItem::sipProtect_readImmutability(const  ::KConfigGroup& a0)
{
     ::KConfigSkeletonItem::readImmutability(a0);
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setGroup(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setGroup(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_group(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_group(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->group());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_group, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setKey(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setKey(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setKey, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_key(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_key(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->key());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_key, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setName(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setName, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_name(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_name, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setLabel(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setLabel, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_label(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_label, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setToolTip(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setToolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setToolTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setToolTip, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_toolTip(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_toolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->toolTip());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_toolTip, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setWhatsThis(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setWhatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setWhatsThis(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setWhatsThis, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_whatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->whatsThis());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_whatsThis, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_readConfig(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_readConfig(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::KConfig* a0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_KConfig, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_readConfig);
                return NULL;
            }

            sipCpp->readConfig(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_readConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_writeConfig(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_writeConfig(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::KConfig* a0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_KConfig, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_writeConfig);
                return NULL;
            }

            sipCpp->writeConfig(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_writeConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_readDefault(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_readDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::KConfig* a0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_KConfig, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_readDefault);
                return NULL;
            }

            sipCpp->readDefault(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_readDefault, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setProperty(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QVariant* a0;
        int a0State = 0;
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_setProperty);
                return NULL;
            }

            sipCpp->setProperty(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0),sipType_QVariant,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setProperty, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_isEqual(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_isEqual(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::QVariant* a0;
        int a0State = 0;
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_isEqual);
                return NULL;
            }

            sipRes = sipCpp->isEqual(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0),sipType_QVariant,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_isEqual, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_property(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_property(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_property);
                return NULL;
            }

            sipRes = new  ::QVariant(sipCpp->property());

            return sipConvertFromNewType(sipRes,sipType_QVariant,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_property, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_minValue(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_minValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::KConfigSkeletonItem::minValue() : sipCpp->minValue()));

            return sipConvertFromNewType(sipRes,sipType_QVariant,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_minValue, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_maxValue(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_maxValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
             ::QVariant*sipRes;

            sipRes = new  ::QVariant((sipSelfWasArg ? sipCpp-> ::KConfigSkeletonItem::maxValue() : sipCpp->maxValue()));

            return sipConvertFromNewType(sipRes,sipType_QVariant,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_maxValue, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_setDefault(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_setDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_setDefault);
                return NULL;
            }

            sipCpp->setDefault();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_setDefault, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_swapDefault(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_swapDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_KConfigSkeletonItem, sipName_swapDefault);
                return NULL;
            }

            sipCpp->swapDefault();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_swapDefault, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_isImmutable(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_isImmutable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigSkeletonItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isImmutable();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_isImmutable, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeletonItem_readImmutability(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeletonItem_readImmutability(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KConfigGroup* a0;
        sipKConfigSkeletonItem *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KConfigSkeletonItem, &sipCpp, sipType_KConfigGroup, &a0))
        {
            sipCpp->sipProtect_readImmutability(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeletonItem, sipName_readImmutability, NULL);

    return NULL;
}


/* Call the instance's destructor. */
extern "C" {static void release_KConfigSkeletonItem(void *, int);}
static void release_KConfigSkeletonItem(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipKConfigSkeletonItem *>(sipCppV);
    else
        delete reinterpret_cast< ::KConfigSkeletonItem *>(sipCppV);
}


extern "C" {static void dealloc_KConfigSkeletonItem(sipSimpleWrapper *);}
static void dealloc_KConfigSkeletonItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipKConfigSkeletonItem *>(sipGetAddress(sipSelf))->sipPySelf = NULL;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_KConfigSkeletonItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_KConfigSkeletonItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KConfigSkeletonItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipKConfigSkeletonItem *sipCpp = 0;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::QString* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "J1J1", sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State))
        {
            sipCpp = new sipKConfigSkeletonItem(*a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return NULL;
}


static PyMethodDef methods_KConfigSkeletonItem[] = {
    {SIP_MLNAME_CAST(sipName_group), meth_KConfigSkeletonItem_group, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isEqual), meth_KConfigSkeletonItem_isEqual, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isImmutable), meth_KConfigSkeletonItem_isImmutable, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_key), meth_KConfigSkeletonItem_key, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_label), meth_KConfigSkeletonItem_label, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_maxValue), meth_KConfigSkeletonItem_maxValue, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_minValue), meth_KConfigSkeletonItem_minValue, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_name), meth_KConfigSkeletonItem_name, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_property), meth_KConfigSkeletonItem_property, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readConfig), meth_KConfigSkeletonItem_readConfig, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readDefault), meth_KConfigSkeletonItem_readDefault, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readImmutability), (PyCFunction)meth_KConfigSkeletonItem_readImmutability, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_setDefault), meth_KConfigSkeletonItem_setDefault, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setGroup), meth_KConfigSkeletonItem_setGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setKey), meth_KConfigSkeletonItem_setKey, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setLabel), meth_KConfigSkeletonItem_setLabel, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setName), meth_KConfigSkeletonItem_setName, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setProperty), meth_KConfigSkeletonItem_setProperty, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setToolTip), meth_KConfigSkeletonItem_setToolTip, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setWhatsThis), meth_KConfigSkeletonItem_setWhatsThis, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_swapDefault), meth_KConfigSkeletonItem_swapDefault, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_toolTip), meth_KConfigSkeletonItem_toolTip, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_whatsThis), meth_KConfigSkeletonItem_whatsThis, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_writeConfig), meth_KConfigSkeletonItem_writeConfig, METH_VARARGS, NULL}
};


static pyqt5ClassPluginDef plugin_KConfigSkeletonItem = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KConfigSkeletonItem = {
    {
        -1,
        0,
        0,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KConfigSkeletonItem,
        {0},
        &plugin_KConfigSkeletonItem
    },
    {
        sipNameNr_KConfigSkeletonItem,
        {0, 0, 1},
        24, methods_KConfigSkeletonItem,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    init_type_KConfigSkeletonItem,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KConfigSkeletonItem,
    0,
    0,
    0,
    release_KConfigSkeletonItem,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
